@@ -72,6 +72,9 @@ class Blockchain(object):
         # database; sqlite3 makes multiple accesses to the same database OK)
         self.fork_data = sqliteshelf.SQLiteShelf(store_filename, 
             table="fork", lazy=True)
+            
+        # Remember the store filename for periodic filesize checkups
+        self.store_filename = store_filename
         
         # Keep the highest Block around, so we can easily get the top of the
         # highest fork.
@@ -1330,7 +1333,7 @@ class Blockchain(object):
                         return self.blockstore[position_b]
                     
 
-            if genesis_a.get_hash() == genesis_b.get_hash():
+            if genesis_a.block_hash() == genesis_b.block_hash():
                 # Double-check the independence of the independent genesis
                 # blocks.
                 raise Exception("Stepped back all the way to independent "
