@@ -3,6 +3,7 @@ ServerFactory.py: contains the ServerFactory class.
 
 """
 
+import logging
 from twisted.internet import protocol
 
 from pybc.BlockchainProtocol import BlockchainProtocol
@@ -31,7 +32,7 @@ class ServerFactory(protocol.ServerFactory):
         
         """
         
-        print "Server got connection from ", addr
+        logging.info("Server got connection from {}".format(addr))
         
         # Make a new BlockchainProtocol that knows we are its factory. It will
         # then talk to our peer.
